# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'dualscale.ui'
#
# Created by: PyQt5 UI code generator 5.13.0
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(638, 627)
        self.gridLayout = QtWidgets.QGridLayout(Form)
        self.gridLayout.setObjectName("gridLayout")
        self.glayout = QtWidgets.QGridLayout()
        self.glayout.setObjectName("glayout")
        self.gridLayout.addLayout(self.glayout, 0, 0, 1, 1)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))



# This file has been generated


build_system = 'AppVeyor'
build_id = '35331745'
build_number = '550'
build_version = '1.0.550'
job_id = 'xpagku1jolu68p7v'
job_url = 'https://ci.appveyor.com/project/KyleAltendorf/stlib/build/job/xpagku1jolu68p7v'
